// A basic everyday NeoPixel strip test program.

// NEOPIXEL BEST PRACTICES for most reliable operation:
// - Add 1000 uF CAPACITOR between NeoPixel strip's + and - connections.
// - MINIMIZE WIRING LENGTH between microcontroller board and first pixel.
// - NeoPixel strip's DATA-IN should pass through a 300-500 OHM RESISTOR.
// - AVOID connecting NeoPixels on a LIVE CIRCUIT. If you must, ALWAYS
//   connect GROUND (-) first, then +, then data.
// - When using a 3.3V microcontroller with a 5V-powered NeoPixel strip,
//   a LOGIC-LEVEL CONVERTER on the data line is STRONGLY RECOMMENDED.
// (Skipping these may work OK on your workbench but can fail in the field)

#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
 #include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif

// Which pin on the Arduino is connected to the NeoPixels?
// On a Trinket or Gemma we suggest changing this to 1:
#define LED_PIN    13

// How many NeoPixels are attached to the Arduino?
#define LED_COUNT 31

// Declare our NeoPixel strip object:
Adafruit_NeoPixel strip(LED_COUNT, LED_PIN, NEO_GRB + NEO_KHZ800);
// Argument 1 = Number of pixels in NeoPixel strip
// Argument 2 = Arduino pin number (most are valid)
// Argument 3 = Pixel type flags, add together as needed:
//   NEO_KHZ800  800 KHz bitstream (most NeoPixel products w/WS2812 LEDs)
//   NEO_KHZ400  400 KHz (classic 'v1' (not v2) FLORA pixels, WS2811 drivers)
//   NEO_GRB     Pixels are wired for GRB bitstream (most NeoPixel products)
//   NEO_RGB     Pixels are wired for RGB bitstream (v1 FLORA pixels, not v2)
//   NEO_RGBW    Pixels are wired for RGBW bitstream (NeoPixel RGBW products)


// setup() function -- runs once at startup --------------------------------

void setup() {
  strip.begin();           // INITIALIZE NeoPixel strip object (REQUIRED)
  strip.show();            // Turn OFF all pixels ASAP
  strip.setBrightness(50); // Set BRIGHTNESS to about 1/5 (max = 255)
  // initialize the pushbutton pin as an input:
  pinMode(2, INPUT_PULLUP);
  pinMode(3, INPUT_PULLUP);
  pinMode(4, INPUT_PULLUP);
  pinMode(5, INPUT_PULLUP);
  pinMode(6, INPUT_PULLUP);
  pinMode(7, INPUT_PULLUP);
}


// loop() function -- runs repeatedly as long as board is on ---------------

void loop(){
  
  int button1State = digitalRead(2);
  int button2State = digitalRead(3);
  int button3State = digitalRead(4);
  int button4State = digitalRead(5);
  int button5State = digitalRead(6);
  int button6State = digitalRead(7);
  
    // check if the pushbutton is pressed. If it is, the buttonState is HIGH:
  if (button1State == LOW) {
    // turn LED on:
    segment1(strip.Color(255,   0,   0), 50); // Red
    segment7(strip.Color(255,   0,   0), 50); // Red
  } else {
    // turn LED off:
    //segment1(strip.Color(0,   0,   0), 0); // off
  }
  if (button2State == LOW) {
    // turn LED on:
    segment2(strip.Color(255,   0,   0), 50); // Red
  } else {
    // turn LED off:
    //segment1(strip.Color(0,   0,   0), 0); // off
  }
    if (button3State == LOW) {
    // turn LED on:
    segment3(strip.Color(255,   0,   0), 50); // Red
  } else {
    // turn LED off:
    //segment1(strip.Color(0,   0,   0), 0); // off
  }
  
    if (button4State == LOW) {
    // turn LED on:
    segment4(strip.Color(255,   0,   0), 50); // Red
  } else {
    // turn LED off:
    //segment1(strip.Color(0,   0,   0), 0); // off
  }
  
}

void segment1(uint32_t color, int wait) {
  for(int i=0; i<=5; i++) { // For each pixel between x and y
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
  }
      strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
}
void segment2(uint32_t color, int wait) {
  for(int i=6; i<=11; i++) { // For each pixel between x and y
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
  }
  strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
}
void segment3(uint32_t color, int wait) {
  for(int i=12; i<=17; i++) { // For each pixel between x and y
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
  }
  strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
}
void segment4(uint32_t color, int wait) {
  for(int i=18; i<=23; i++) { // For each pixel between x and y
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
  }
  strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
}

void segment5(uint32_t color, int wait) {
  for(int i=24; i<=30; i++) { // For each pixel between x and y
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
  }
  strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
}

void segment6(uint32_t color, int wait) {
  for(int i=31; i<=35; i++) { // For each pixel between x and y
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
  }
  strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
}

void segment7(uint32_t color, int wait) {
  for(int i=36; i<=39; i++) { // For each pixel between x and y
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
  }
  strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
}


// Some functions of our own for creating animated effects -----------------

// Fill strip pixels one after another with a color. Strip is NOT cleared
// first; anything there will be covered pixel by pixel. Pass in color
// (as a single 'packed' 32-bit value, which you can get by calling
// strip.Color(red, green, blue) as shown in the loop() function above),
// and a delay time (in milliseconds) between pixels.
void colorWipe(uint32_t color, int wait) {
  for(int i=0; i<strip.numPixels(); i++) { // For each pixel in strip...
    strip.setPixelColor(i, color);         //  Set pixel's color (in RAM)
    strip.show();                          //  Update strip to match
    delay(wait);                           //  Pause for a moment
  }
}
